==> owncloud-4.0.4.tgz: owncloud/apps/calendar/l10n/ia.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Necun calendarios trovate.",
"No events found." => "Nulle eventos trovate.",
"New Timezone:" => "Nove fuso horari",
"Invalid request" => "Requesta invalide.",
"Calendar" => "Calendario",
"Birthday" => "Anniversario de nativitate",
"Business" => "Affaires",
"Call" => "Appello",
"Clients" => "Clientes",
"Holidays" => "Dies feriate",
"Meeting" => "Incontro",
"Other" => "Altere",
"Personal" => "Personal",
"Projects" => "Projectos",
"Questions" => "Demandas",
"Work" => "Travalio",
"unnamed" => "sin nomine",
"Does not repeat" => "Non repite",
"Daily" => "Quotidian",
"Weekly" => "Septimanal",
"Every Weekday" => "Cata die",
"Monthly" => "Mensual",
"Yearly" => "Cata anno",
"never" => "nunquam",
"by date" => "per data",
"Monday" => "Lunedi",
"Tuesday" => "Martedi",
"Wednesday" => "Mercuridi",
"Thursday" => "Jovedi",
"Friday" => "Venerdi",
"Saturday" => "Sabbato",
"Sunday" => "Dominica",
"first" => "prime",
"second" => "secunde",
"third" => "tertie",
"last" => "ultime",
"January" => "januario",
"February" => "Februario",
"March" => "Martio",
"April" => "April",
"May" => "Mai",
"June" => "Junio",
"July" => "Julio",
"August" => "Augusto",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Decembre",
"by events date" => "per data de eventos",
"by day and month" => "per dia e mense",
"Date" => "Data",
"All day" => "Omne die",
"New Calendar" => "Nove calendario",
"Missing fields" => "Campos incomplete",
"Title" => "Titulo",
"From Date" => "Data de initio",
"From Time" => "Hora de initio",
"To Date" => "Data de fin",
"To Time" => "Hora de fin",
"Week" => "Septimana",
"Month" => "Mense",
"List" => "Lista",
"Today" => "Hodie",
"Calendars" => "Calendarios",
"Choose active calendars" => "Selectionar calendarios active",
"Your calendars" => "Tu calendarios",
"Download" => "Discarga",
"Edit" => "Modificar",
"Delete" => "Deler",
"New calendar" => "Nove calendario",
"Edit calendar" => "Modificar calendario",
"Active" => "Active",
"Calendar color" => "Color de calendario",
"Save" => "Salveguardar",
"Submit" => "Inviar",
"Cancel" => "Cancellar",
"Edit an event" => "Modificar evento",
"Export" => "Exportar",
"Share" => "Compartir",
"Title of the Event" => "Titulo del evento.",
"Category" => "Categoria",
"Edit categories" => "Modificar categorias",
"From" => "Ab",
"To" => "A",
"Advanced options" => "Optiones avantiate",
"Location" => "Loco",
"Location of the Event" => "Loco del evento.",
"Description" => "Description",
"Description of the Event" => "Description del evento",
"Repeat" => "Repeter",
"Advanced" => "Avantiate",
"Select weekdays" => "Seliger dies del septimana",
"Select days" => "Seliger dies",
"Select months" => "Seliger menses",
"Select weeks" => "Seliger septimanas",
"Interval" => "Intervallo",
"End" => "Fin",
"Import a calendar file" => "Importar un file de calendario",
"Please choose the calendar" => "Selige el calendario",
"create a new calendar" => "crear un nove calendario",
"Name of new calendar" => "Nomine del calendario",
"Import" => "Importar",
"Close Dialog" => "Clauder dialogo",
"Create a new event" => "Crear un nove evento",
"View an event" => "Vide un evento",
"No categories selected" => "Nulle categorias seligite",
"Select category" => "Selectionar categoria",
"of" => "de",
"at" => "in",
"Timezone" => "Fuso horari",
"First day of the week" => "Prime die del septimana",
"Users" => "Usatores",
"Groups" => "Gruppos"
);

==> owncloud-5.0.9.tgz: owncloud/apps/calendar/l10n/ia.php <==
<?php $TRANSLATIONS = array(
"No calendars found." => "Necun calendarios trovate.",
"No events found." => "Nulle eventos trovate.",
"New Timezone:" => "Nove fuso horari",
"Invalid request" => "Requesta invalide.",
"Calendar" => "Calendario",
"Sunday" => "Dominica",
"Monday" => "Lunedi",
"Tuesday" => "Martedi",
"Wednesday" => "Mercuridi",
"Thursday" => "Jovedi",
"Friday" => "Venerdi",
"Saturday" => "Sabbato",
"Sun." => "Dom.",
"Mon." => "Lun.",
"Tue." => "Mar.",
"Wed." => "Mer.",
"Thu." => "Jov.",
"Fri." => "Ven.",
"Sat." => "Sab.",
"January" => "januario",
"February" => "Februario",
"March" => "Martio",
"April" => "April",
"May" => "Mai",
"June" => "Junio",
"July" => "Julio",
"August" => "Augusto",
"September" => "Septembre",
"October" => "Octobre",
"November" => "Novembre",
"December" => "Decembre",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai.",
"Jun." => "Jun.",
"Jul." => "Jul.",
"Aug." => "Aug.",
"Dec." => "Dec.",
"All day" => "Omne die",
"New Calendar" => "Nove calendario",
"Title" => "Titulo",
"From Date" => "Data de initio",
"From Time" => "Hora de initio",
"To Date" => "Data de fin",
"To Time" => "Hora de fin",
"Birthday" => "Anniversario de nativitate",
"Business" => "Affaires",
"Call" => "Appello",
"Clients" => "Clientes",
"Holidays" => "Dies feriate",
"Meeting" => "Incontro",
"Other" => "Altere",
"Personal" => "Personal",
"Projects" => "Projectos",
"Questions" => "Demandas",
"Work" => "Travalio",
"unnamed" => "sin nomine",
"Does not repeat" => "Non repite",
"Daily" => "Quotidian",
"Weekly" => "Septimanal",
"Every Weekday" => "Cata die",
"Monthly" => "Mensual",
"Yearly" => "Cata anno",
"never" => "nunquam",
"by date" => "per data",
"first" => "prime",
"second" => "secunde",
"third" => "tertie",
"last" => "ultime",
"by events date" => "per data de eventos",
"by day and month" => "per dia e mense",
"Date" => "Data",
"Week" => "Septimana",
"Month" => "Mense",
"List" => "Lista",
"Today" => "Hodie",
"Settings" => "Configurationes",
"Your calendars" => "Tu calendarios",
"Download" => "Discarga",
"Edit" => "Modificar",
"Delete" => "Deler",
"New calendar" => "Nove calendario",
"Edit calendar" => "Modificar calendario",
"Active" => "Active",
"Calendar color" => "Color de calendario",
"Save" => "Salveguardar",
"Submit" => "Inviar",
"Cancel" => "Cancellar",
"Edit an event" => "Modificar evento",
"Export" => "Exportar",
"Share" => "Compartir",
"Title of the Event" => "Titulo del evento.",
"Category" => "Categoria",
"Edit categories" => "Modificar categorias",
"From" => "Ab",
"To" => "A",
"Advanced options" => "Optiones avantiate",
"Location" => "Loco",
"Location of the Event" => "Loco del evento.",
"Description" => "Description",
"Description of the Event" => "Description del evento",
"Repeat" => "Repeter",
"Advanced" => "Avantiate",
"Select weekdays" => "Seliger dies del septimana",
"Select days" => "Seliger dies",
"Select months" => "Seliger menses",
"Select weeks" => "Seliger septimanas",
"Interval" => "Intervallo",
"End" => "Fin",
"create a new calendar" => "crear un nove calendario",
"Import a calendar file" => "Importar un file de calendario",
"Name of new calendar" => "Nomine del calendario",
"Import" => "Importar",
"Close Dialog" => "Clauder dialogo",
"Create a new event" => "Crear un nove evento",
"View an event" => "Vide un evento",
"No categories selected" => "Nulle categorias seligite",
"of" => "de",
"at" => "in",
"Timezone" => "Fuso horari",
"more info" => "plus info",
"iOS/OS X" => "iOS/OS X"
);
